regIndex: Calculate fish osmoregulation index according to fitted cubic...

View source: R/regulation_area_function.R

regIndexR Documentation

Calculate fish osmoregulation index according to fitted cubic function

Description

Calculate fish osmoregulation index according to a fitted cubic function of MO2 vs. kpa and produce associated plot.

Usage

regIndex(kpa, MO2, period, plot = TRUE)

Arguments

kpa

vector of kpa (x)

MO2

vector of MO2 (y)

period

vector coded to indicate measurements under "SMR"

plot

should a plot of the fitted function be produced?

Value

List containing fitted model coefficients, Efron's pseudo R2, regulation index, and p50

Examples

## Not run: 
# with plot
regIndex(data$kpa, data$MO2, data$period)
# without plot
data.frame(t(unlist(regIndex(data$kpa, data$MO2, data$period, plot = FALSE))))

## End(Not run)

kyledettloff-NOAA/fishphysio documentation built on Aug. 27, 2023, 4:46 a.m.