View source: R/regulation_area_function.R
| regIndex | R Documentation |
Calculate fish osmoregulation index according to a fitted cubic function of MO2 vs. kpa and produce associated plot.
regIndex(kpa, MO2, period, plot = TRUE)
kpa |
vector of kpa (x) |
MO2 |
vector of MO2 (y) |
period |
vector coded to indicate measurements under "SMR" |
plot |
should a plot of the fitted function be produced? |
List containing fitted model coefficients, Efron's pseudo R2, regulation index, and p50
## Not run:
# with plot
regIndex(data$kpa, data$MO2, data$period)
# without plot
data.frame(t(unlist(regIndex(data$kpa, data$MO2, data$period, plot = FALSE))))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.